@@ -11,7 +11,11 @@ from .base.types import (
     StackOrientation,
     StackDistribution,
     ImagePosition,
-    Date
+    Date,
+    AlertResponse,
+    AlertStyle,
+    DialogResponse,
+    ProgressStyle
 )
 from .base.binding import (
     bindable,
